@@ -8,4 +8,6 @@ from django_gitolite import views
 
 urlpatterns = [
     url(r'^$', views.index, name='index'),
+    url(r'^(?P<path>([A-Za-z0-9-+]+/)*[A-Za-z0-9-+]+)/$',
+        views.repo, name='repo'),
 ]
